Class: Dependabot::Uv::LanguageVersionManager

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/dependabot/uv/language_version_manager.rb

Constant Summary collapse

PRE_INSTALLED_PYTHON_VERSIONS =

This list must match the versions specified at the top of ‘python/Dockerfile`

%w(
  3.13.2
  3.12.9
  3.11.11
  3.10.16
  3.9.21
).freeze

Instance Method Summary collapse

Constructor Details

#initialize(python_requirement_parser:) ⇒ LanguageVersionManager

Returns a new instance of LanguageVersionManager.



22
23
24
# File 'lib/dependabot/uv/language_version_manager.rb', line 22

def initialize(python_requirement_parser:)
  @python_requirement_parser = python_requirement_parser
end

Instance Method Details

#install_required_pythonObject



27
28
29
30
31
32
33
34
# File 'lib/dependabot/uv/language_version_manager.rb', line 27

def install_required_python
  # The leading space is important in the version check
  return if SharedHelpers.run_shell_command("pyenv versions").include?(" #{python_major_minor}.")

  SharedHelpers.run_shell_command(
    "tar -axf /usr/local/.pyenv/versions/#{python_version}.tar.zst -C /usr/local/.pyenv/versions"
  )
end

#installed_versionObject



37
38
39
40
41
42
43
# File 'lib/dependabot/uv/language_version_manager.rb', line 37

def installed_version
  # Use `pyenv exec` to query the active Python version
  output, _status = SharedHelpers.run_shell_command("pyenv exec python --version")
  version = output.strip.split.last # Extract the version number (e.g., "3.13.1")

  T.must(version)
end

#python_major_minorObject



46
47
48
# File 'lib/dependabot/uv/language_version_manager.rb', line 46

def python_major_minor
  @python_major_minor ||= T.let(T.must(Uv::Version.new(python_version).segments[0..1]).join("."), T.untyped)
end

#python_requirement_stringObject



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/dependabot/uv/language_version_manager.rb', line 56

def python_requirement_string
  if user_specified_python_version
    if user_specified_python_version.start_with?(/\d/)
      parts = user_specified_python_version.split(".")
      parts.fill("*", (parts.length)..2).join(".")
    else
      user_specified_python_version
    end
  else
    python_version_matching_imputed_requirements || PRE_INSTALLED_PYTHON_VERSIONS.first
  end
end

#python_versionObject



51
52
53
# File 'lib/dependabot/uv/language_version_manager.rb', line 51

def python_version
  @python_version ||= T.let(python_version_from_supported_versions, T.nilable(String))
end

#python_version_from_supported_versionsObject

Raises:

  • (ToolVersionNotSupported)


70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/dependabot/uv/language_version_manager.rb', line 70

def python_version_from_supported_versions
  requirement_string = python_requirement_string

  # If the requirement string isn't already a range (eg ">3.10"), coerce it to "major.minor.*".
  # The patch version is ignored because a non-matching patch version is unlikely to affect resolution.
  requirement_string = requirement_string.gsub(/\.\d+$/, ".*") if requirement_string.start_with?(/\d/)

  # Try to match one of our pre-installed Python versions
  requirement = T.must(Uv::Requirement.requirements_array(requirement_string).first)
  version = PRE_INSTALLED_PYTHON_VERSIONS.find { |v| requirement.satisfied_by?(Uv::Version.new(v)) }
  return version if version

  # Otherwise we have to raise
  supported_versions = PRE_INSTALLED_PYTHON_VERSIONS.map { |x| x.gsub(/\.\d+$/, ".*") }.join(", ")
  raise ToolVersionNotSupported.new("Python", python_requirement_string, supported_versions)
end

#python_version_matching(requirements) ⇒ Object



102
103
104
105
106
107
108
109
110
111
# File 'lib/dependabot/uv/language_version_manager.rb', line 102

def python_version_matching(requirements)
  PRE_INSTALLED_PYTHON_VERSIONS.find do |version_string|
    version = Uv::Version.new(version_string)
    requirements.all? do |req|
      next req.any? { |r| r.satisfied_by?(version) } if req.is_a?(Array)

      req.satisfied_by?(version)
    end
  end
end

#python_version_matching_imputed_requirementsObject



93
94
95
96
97
98
99
# File 'lib/dependabot/uv/language_version_manager.rb', line 93

def python_version_matching_imputed_requirements
  compiled_file_python_requirement_markers =
    @python_requirement_parser.imputed_requirements.map do |r|
      Dependabot::Uv::Requirement.new(r)
    end
  python_version_matching(compiled_file_python_requirement_markers)
end

#user_specified_python_versionObject



88
89
90
# File 'lib/dependabot/uv/language_version_manager.rb', line 88

def user_specified_python_version
  @python_requirement_parser.user_specified_requirements.first
end