Class: Dependabot::Uv::FileUpdater
- Inherits:
-
FileUpdaters::Base
- Object
- FileUpdaters::Base
- Dependabot::Uv::FileUpdater
- Extended by:
- T::Sig
- Defined in:
- lib/dependabot/uv/file_updater.rb,
lib/dependabot/uv/file_updater/lock_file_updater.rb,
lib/dependabot/uv/file_updater/pyproject_preparer.rb,
lib/dependabot/uv/file_updater/compile_file_updater.rb,
lib/dependabot/uv/file_updater/requirement_replacer.rb,
lib/dependabot/uv/file_updater/version_config_parser.rb,
lib/dependabot/uv/file_updater/lock_file_error_handler.rb,
lib/dependabot/uv/file_updater/requirement_file_updater.rb
Defined Under Namespace
Classes: CompileFileUpdater, LockFileErrorHandler, LockFileUpdater, PyprojectPreparer, VersionConfigParser
Constant Summary collapse
- RequirementReplacer =
UV uses the same requirement replacement logic as Python. Both ecosystems share RequirementParser, NativeHelpers, and NameNormaliser via aliases, so we reuse Python’s implementation.
Dependabot::Python::FileUpdater::RequirementReplacer
- RequirementFileUpdater =
UV uses the same requirement file update logic as Python. Both ecosystems share RequirementReplacer and NativeHelpers via aliases, so we reuse Python’s implementation.
Dependabot::Python::FileUpdater::RequirementFileUpdater
Instance Method Summary collapse
Instance Method Details
#updated_dependency_files ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/dependabot/uv/file_updater.rb', line 20 def updated_dependency_files updated_files = updated_pip_compile_based_files updated_files += updated_uv_lock_files if updated_files.none? || updated_files.sort_by(&:name) == dependency_files.sort_by(&:name) raise "No files have changed!" end updated_files end |